==> moodle_1.3.1.orig.tar.gz: moodle/lang/ko/dialogue.php <==
<?PHP // $Id: dialogue.php,v 1.1 2004/02/10 06:38:11 moodler Exp $ 
      // dialogue.php - created with Moodle 1.2 development (2004013100)


$string['addmynewentries'] = '  ߰ϱ';
$string['addmynewentry'] = '  ߰';
$string['addsubject'] = ' ߰';
$string['allowmultiple'] = '    ȭ   ְ';
$string['allowstudentdialogues'] = 'л л ȭ ϱ';
$string['close'] = '';
$string['closed'] = '';
$string['confirmclosure'] = ' $a ȭ  Ϸ մϴ. ѹ ϸ ٽ   Ϥ. ȭ ϸ  ȭ    , ο  ߰  ϴ.   ȭ  ұ?';
$string['deleteafter'] = '(Days) Ŀ  ȭ ';
$string['dialogueclosed'] = 'ȭ ';
$string['dialogueintro'] = 'ȭ Ұ';
$string['dialoguemail'] = '$a->userfrom  ſ \'$a->dialogue\'  ÷Ƚϴ.

Ʒ ּҸ Ŭϸ ߰    ֽϴ.:

    $a->url';
$string['dialoguemailhtml'] = '$a->userfrom  ſ  ÷Ƚϴ.\'<i>$a->dialogue</i>\'<br /><br />

Ʒ ּҸ Ŭϸ ߰    ֽϴ.<a href=\"$a->url\">dialogue</a>.';
$string['dialoguename'] = 'ȭ ̸';
$string['dialogueopened'] = '$a   ȭ';
$string['dialoguewith'] = '$a  ȭ';
$string['everybody'] = '';
$string['furtherinformation'] = ' ';
$string['lastentry'] = ' ׸';
$string['maildefault'] = ' ⺻';
$string['modulename'] = 'ȭ';
$string['modulenameplural'] = 'ȭ';
$string['namehascloseddialogue'] = '$a  ȭ ';
$string['newdialogueentries'] = 'ο ȭ ';
$string['newentry'] = 'ο ׸';
$string['noavailablepeople'] = '̿  ִ ȭ ϴ.';
$string['nopersonchosen'] = '  ';
$string['nosubject'] = ' Է ';
$string['notextentered'] = ' Է ';
$string['notstarted'] = '  ȭ  ʾҽϴ.';
$string['notyetseen'] = '  ';
$string['numberofentries'] = ' ';
$string['numberofentriesadded'] = '߰  : $a';
$string['of'] = 'of';
$string['onwrote'] = 'On $a wrote';
$string['onyouwrote'] = 'On $a you wrote';
$string['open'] = 'Open';
$string['openadialoguewith'] = ' ȭ ';
$string['opendialogue'] = 'ȭ ';
$string['opendialogueentries'] = 'ȭ  ';
$string['pane0'] = 'ȭ ';
$string['pane1'] = '亯 ٸ  : $a ';
$string['pane1one'] = '1   亯 ٸϴ.';
$string['pane2'] = '$a   ٸ  亯 ٸϴ.';
$string['pane2one'] = '1   ٸ  亯 ٸϴ.';
$string['pane3'] = '$a   ȭ';
$string['pane3one'] = '1   ȭ';
$string['seen'] = ' $a ';
$string['sendmailmessages'] = 'ο ׸ Ϸ  ּ';
$string['status'] = 'Ȳ';
$string['studenttostudent'] = 'л л';
$string['subject'] = '';
$string['subjectadded'] = ' ߰';
$string['teachertostudent'] = '簡 л';
$string['typefirstentry'] = '⿡ ù°  .';
$string['typefollowup'] = '⿡   ';
$string['typeofdialogue'] = 'ȭ ';
$string['typereply'] = '⿡  ';
$string['viewallentries'] = '$a ȭ  ';

?>

==> moodle_1.5.2.orig.tar.gz: moodle/lang/ko/dialogue.php <==
<?PHP // $Id$



$string['addmynewentries'] = '  ߰ϱ';
$string['addmynewentry'] = '  ߰';
$string['addsubject'] = ' ߰';
$string['allowmultiple'] = '    ȭ   ְ';
$string['allowstudentdialogues'] = 'л л ȭ ϱ';
$string['close'] = '';
$string['closed'] = '';
$string['confirmclosure'] = ' $a ȭ  Ϸ մϴ. ѹ ϸ ٽ   Ϥ. ȭ ϸ  ȭ    , ο  ߰  ϴ.   ȭ  ұ?';
$string['deleteafter'] = '(Days) Ŀ  ȭ ';
$string['dialogueclosed'] = 'ȭ ';
$string['dialogueintro'] = 'ȭ Ұ';
$string['dialoguemail'] = '$a->userfrom  ſ \'$a->dialogue\'  ÷Ƚϴ.
Ʒ ּҸ Ŭϸ ߰    ֽϴ.:
    $a->url';
$string['dialoguemailhtml'] = '$a->userfrom  ſ  ÷Ƚϴ.\'<i>$a->dialogue</i>\'<br /><br />
Ʒ ּҸ Ŭϸ ߰    ֽϴ.<a href=\"$a->url\">dialogue</a>.';
$string['dialoguename'] = 'ȭ ̸';
$string['dialogueopened'] = '$a   ȭ';
$string['dialoguewith'] = '$a  ȭ';
$string['everybody'] = '';
$string['furtherinformation'] = ' ';
$string['lastentry'] = ' ׸';
$string['maildefault'] = ' ⺻';
$string['mailnotification'] = ' ';
$string['modulename'] = 'ȭ';
$string['modulenameplural'] = 'ȭ';
$string['namehascloseddialogue'] = '$a  ȭ ';
$string['newdialogueentries'] = 'ο ȭ ';
$string['newentry'] = 'ο ׸';
$string['noavailablepeople'] = '̿  ִ ȭ ϴ.';
$string['nopersonchosen'] = '  ';
$string['nosubject'] = ' Է ';
$string['notextentered'] = ' Է ';
$string['notstarted'] = '  ȭ  ʾҽϴ.';
$string['notyetseen'] = '  ';
$string['numberofentries'] = ' ';
$string['numberofentriesadded'] = '߰  : $a';
$string['of'] = '';
$string['onwrote'] = ' ۼϿϴ. ';
$string['onyouwrote'] = '  ۼϿϴ.';
$string['open'] = '';
$string['openadialoguewith'] = ' ȭ ';
$string['opendialogue'] = 'ȭ ';
$string['opendialogueentries'] = 'ȭ  ';
$string['pane0'] = 'ȭ ';
$string['pane1'] = '亯 ٸ  : $a ';
$string['pane1one'] = '1   亯 ٸϴ.';
$string['pane2'] = '$a   ٸ  亯 ٸϴ.';
$string['pane2one'] = '1   ٸ  亯 ٸϴ.';
$string['pane3'] = '$a   ȭ';
$string['pane3one'] = '1   ȭ';
$string['seen'] = ' $a ';
$string['sendmailmessages'] = 'ο ׸ Ϸ  ּ';
$string['status'] = 'Ȳ';
$string['studenttostudent'] = 'л л';
$string['subject'] = '';
$string['subjectadded'] = ' ߰';
$string['teachertostudent'] = '簡 л';
$string['typefirstentry'] = '⿡ ù°  .';
$string['typefollowup'] = '⿡   ';
$string['typeofdialogue'] = 'ȭ ';
$string['typereply'] = '⿡  ';
$string['viewallentries'] = '$a ȭ  ';
?>
